
Spectrum Analysis
=================

.. automodapi:: grizli.grismconf
    :no-inheritance-diagram:

.. automodapi:: grizli.model
    :no-inheritance-diagram:
    :skip: Table, OrderedDict
    
.. automodapi:: grizli.multifit
    :no-inheritance-diagram:
    :skip: Table, OrderedDict, GroupFitter

.. automodapi:: grizli.fitting
    :no-inheritance-diagram:
    :skip: OrderedDict, Planck15

Utilities
=========
.. automodapi:: grizli.utils
    :no-inheritance-diagram:
    :skip: OrderedDict

.. automodapi:: grizli.utils_numba.interp
    :no-inheritance-diagram:

.. automodapi:: grizli.utils_numba.disperse
    :no-inheritance-diagram:

Catalog tools
=============
.. automodapi:: grizli.catalog
    :no-inheritance-diagram:

Pipeline tools
==============
.. automodapi:: grizli.pipeline.default_params
    :no-inheritance-diagram:

.. automodapi:: grizli.pipeline.auto_script
    :no-inheritance-diagram:
    :skip: get_yml_parameters, write_params_to_yml

.. automodapi:: grizli.pipeline.photoz
    :no-inheritance-diagram:

Simulations
===========
Some basic tools for simulating HST/JWST/Roman grism data.  See `multimission_simulaation.ipynb <https://nbviewer.jupyter.org/github/gbrammer/grizli-notebooks/blob/main/multimission-simulation.ipynb>`__ for some examples.

.. automodapi:: grizli.fake_image
    :no-inheritance-diagram:

